Re:Parallelizing the Naughty Dog Engine Using Fibers [video]
by byuu on Friday May 27, 2016 @11:56PM
(#11790516)
Just a fair warning, setcontext is horrendously slow. It seems to be doing kernel transitions or something. It's about 600 times slower than longjmp with jmpbuf stack pointer hacking, which is itself already about twice as slow as an ideal assembly version.
[ Parent
| on HN ]
There are no comments on this comment yet.